pub struct EncounterEntry {
pub id: i32,
pub name: String,
pub order_index: i32,
pub dungeon_encounter_id: i32,
pub ui_map_id: i32,
pub image_file_data_id: i32,
pub image_storage_path: String,
pub creature_display_info_id: i32,
pub ui_model_scene_id: i32,
}Fields
id: i32name: Stringorder_index: i32dungeon_encounter_id: i32ui_map_id: i32image_file_data_id: i32image_storage_path: Stringcreature_display_info_id: i32ui_model_scene_id: i32Trait Implementations
Sourceimpl Clone for EncounterEntry
impl Clone for EncounterEntry
Sourcefn clone(&self) -> EncounterEntry
fn clone(&self) -> EncounterEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncounterEntry
impl Debug for EncounterEntry
Sourceimpl Default for EncounterEntry
impl Default for EncounterEntry
Sourcefn default() -> EncounterEntry
fn default() -> EncounterEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EncounterEntry
impl<'de> Deserialize<'de> for EncounterEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EncounterEntry
impl JsonSchema for EncounterEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EncounterEntry
impl RefUnwindSafe for EncounterEntry
impl Send for EncounterEntry
impl Sync for EncounterEntry
impl Unpin for EncounterEntry
impl UnsafeUnpin for EncounterEntry
impl UnwindSafe for EncounterEntry