pub struct PvpTierRewardEntry {
pub tier_index: i32,
pub tier_name: String,
pub min_rating: i32,
pub max_rating: i32,
pub bracket_id: i32,
pub end_of_match_ilvl: i32,
pub weekly_cache_ilvl: i32,
}Fields
tier_index: i32tier_name: Stringmin_rating: i32max_rating: i32bracket_id: i32end_of_match_ilvl: i32weekly_cache_ilvl: i32Trait Implementations
Sourceimpl Clone for PvpTierRewardEntry
impl Clone for PvpTierRewardEntry
Sourcefn clone(&self) -> PvpTierRewardEntry
fn clone(&self) -> PvpTierRewardEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PvpTierRewardEntry
impl Debug for PvpTierRewardEntry
Sourceimpl Default for PvpTierRewardEntry
impl Default for PvpTierRewardEntry
Sourcefn default() -> PvpTierRewardEntry
fn default() -> PvpTierRewardEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PvpTierRewardEntry
impl<'de> Deserialize<'de> for PvpTierRewardEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PvpTierRewardEntry
impl JsonSchema for PvpTierRewardEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PvpTierRewardEntry
impl RefUnwindSafe for PvpTierRewardEntry
impl Send for PvpTierRewardEntry
impl Sync for PvpTierRewardEntry
impl Unpin for PvpTierRewardEntry
impl UnsafeUnpin for PvpTierRewardEntry
impl UnwindSafe for PvpTierRewardEntry