pub struct TierInstanceEntry {
pub instance_id: i32,
pub instance_name: String,
pub kind: InstanceKind,
pub order_index: i32,
pub map_id: i32,
pub is_mythic_plus: bool,
}Fields
instance_id: i32instance_name: Stringkind: InstanceKindorder_index: i32map_id: i32is_mythic_plus: boolTrait Implementations
Sourceimpl Clone for TierInstanceEntry
impl Clone for TierInstanceEntry
Sourcefn clone(&self) -> TierInstanceEntry
fn clone(&self) -> TierInstanceEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TierInstanceEntry
impl Debug for TierInstanceEntry
Sourceimpl Default for TierInstanceEntry
impl Default for TierInstanceEntry
Sourcefn default() -> TierInstanceEntry
fn default() -> TierInstanceEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TierInstanceEntry
impl<'de> Deserialize<'de> for TierInstanceEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TierInstanceEntry
impl JsonSchema for TierInstanceEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TierInstanceEntry
impl RefUnwindSafe for TierInstanceEntry
impl Send for TierInstanceEntry
impl Sync for TierInstanceEntry
impl Unpin for TierInstanceEntry
impl UnsafeUnpin for TierInstanceEntry
impl UnwindSafe for TierInstanceEntry