pub struct TrackedDungeonEntry {
pub map_challenge_mode_id: i32,
pub map_id: i32,
pub instance_name: String,
}Fields
map_challenge_mode_id: i32map_id: i32instance_name: StringTrait Implementations
Sourceimpl Clone for TrackedDungeonEntry
impl Clone for TrackedDungeonEntry
Sourcefn clone(&self) -> TrackedDungeonEntry
fn clone(&self) -> TrackedDungeonEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackedDungeonEntry
impl Debug for TrackedDungeonEntry
Sourceimpl Default for TrackedDungeonEntry
impl Default for TrackedDungeonEntry
Sourcefn default() -> TrackedDungeonEntry
fn default() -> TrackedDungeonEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TrackedDungeonEntry
impl<'de> Deserialize<'de> for TrackedDungeonEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrackedDungeonEntry
impl JsonSchema for TrackedDungeonEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrackedDungeonEntry
impl RefUnwindSafe for TrackedDungeonEntry
impl Send for TrackedDungeonEntry
impl Sync for TrackedDungeonEntry
impl Unpin for TrackedDungeonEntry
impl UnsafeUnpin for TrackedDungeonEntry
impl UnwindSafe for TrackedDungeonEntry